/*
 * Copyright (c) 2007-2010 Sonatype, Inc.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package org.sonatype.sisu.assembler.gshell.internal;

import java.net.URI;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;

import javax.inject.Singleton;

@Singleton
public class DefaultRepositoryRegistry
    implements RepositoryRegistry
{
    private final Collection<String> repositories;

    public DefaultRepositoryRegistry()
    {
        repositories = new ArrayList<String>();
    }

    public void add( final String repository )
    {
        repositories.add( repository );
    }

    public void remove( final String repository )
    {
        repositories.remove( repository );
    }

    public Collection<String> get()
    {
        return Collections.unmodifiableCollection( repositories );
    }

    public URI[] getAsURI()
    {
        final URI[] uris = new URI[repositories.size()];
        int i = 0;
        for ( final String repository : repositories )
        {
            uris[i++] = URI.create( repository );
        }
        return uris;
    }

    public void removeAll()
    {
        repositories.clear();
    }

    public boolean isEmpty()
    {
        return repositories.isEmpty();
    }

}
