/*
 * Copyright (c) 2007-2010 Sonatype, Inc.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package org.sonatype.sisu.assembler.gshell.internal;

import java.util.ArrayList;
import java.util.List;

import javax.inject.Inject;

import org.sonatype.eclipse.bridge.EclipseInstance;
import org.sonatype.gshell.file.FileSystemAccess;
import org.sonatype.gshell.file.FileSystemAccessImpl;
import org.sonatype.p2.bridge.IUIdentity;
import org.sonatype.p2.bridge.MetadataRepository;
import org.sonatype.p2.bridge.P2Director;
import org.sonatype.p2.bridge.P2ProfileRegistry;
import org.sonatype.p2.bridge.ProfileTimestamp;

import com.google.inject.AbstractModule;
import com.google.inject.TypeLiteral;

public class GuiceModule
    extends AbstractModule
{

    @Override
    protected void configure()
    {
        bind( FileSystemAccess.class ).to( FileSystemAccessImpl.class );
        bind( EclipseInstance.class ).to( PreparedEclipseInstance.class );
        bind( P2ProfileRegistry.class ).toProvider( P2ProfileRegistryProxy.class );
        bind( P2Director.class ).toProvider( P2DirectorProxy.class );
        bind( MetadataRepository.class ).toProvider( MetadataRepositoryProxy.class );
        bind( RepositoryRegistry.class ).to( DefaultRepositoryRegistry.class );

        bind( listOfIUIdentity() ).annotatedWith( ListInstallableCommand.Latest.class ).toInstance(
            new ArrayList<IUIdentity>() );
        bind( listOfProfileTimestamp() ).annotatedWith( ListHistoryCommand.Latest.class ).toInstance(
            new ArrayList<ProfileTimestamp>() );
        bind( listOfIUIdentity() ).annotatedWith( ListInstalledCommand.Latest.class ).toInstance(
            new ArrayList<IUIdentity>() );
        bind( listOfURI() ).annotatedWith( RepositoryListCommand.Latest.class ).toInstance(
            new ArrayList<String>() );
    }

    private TypeLiteral<List<ProfileTimestamp>> listOfProfileTimestamp()
    {
        return new TypeLiteral<List<ProfileTimestamp>>()
        {
        };
    }

    private TypeLiteral<List<IUIdentity>> listOfIUIdentity()
    {
        return new TypeLiteral<List<IUIdentity>>()
        {
        };
    }

    private TypeLiteral<List<String>> listOfURI()
    {
        return new TypeLiteral<List<String>>()
        {
        };
    }

    public static class P2ProfileRegistryProxy
        extends EclipseProxy<P2ProfileRegistry>
    {

        @Inject
        P2ProfileRegistryProxy( final EclipseInstance eclipse )
        {
            super( P2ProfileRegistry.class, eclipse );
        }
    }

    public static class P2DirectorProxy
        extends EclipseProxy<P2Director>
    {

        @Inject
        P2DirectorProxy( final EclipseInstance eclipse )
        {
            super( P2Director.class, eclipse );
        }
    }

    public static class MetadataRepositoryProxy
        extends EclipseProxy<MetadataRepository>
    {

        @Inject
        MetadataRepositoryProxy( final EclipseInstance eclipse )
        {
            super( MetadataRepository.class, eclipse );
        }
    }

}
