/*
 * Copyright (c) 2007-2010 Sonatype, Inc.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package org.sonatype.sisu.assembler.gshell.internal;

import java.io.File;
import java.net.URI;

import org.sonatype.gshell.command.Command;
import org.sonatype.gshell.command.CommandContext;
import org.sonatype.gshell.command.support.CommandActionSupport;
import org.sonatype.gshell.util.cli2.Argument;

import com.google.inject.Inject;

@Command( name = "p2/repository/add" )
public class RepositoryAddCommand
    extends CommandActionSupport
{

    @Argument( required = true )
    private URI uri;

    private final RepositoryRegistry repositoryRegistry;

    @Inject
    public RepositoryAddCommand( final RepositoryRegistry repositoryRegistry )
    {
        assert repositoryRegistry != null;
        this.repositoryRegistry = repositoryRegistry;
    }

    public Object execute( final CommandContext context )
        throws Exception
    {
        assert context != null;

        if ( uri.isAbsolute() )
        {
            repositoryRegistry.add( uri.toASCIIString() );
        }
        else
        {
            // try to make it a file uri
            repositoryRegistry.add( new File( uri.toASCIIString() ).toURI().toASCIIString() );
        }

        return Result.SUCCESS;
    }
}
